Linux 7.4 Begins Landing Patches To Speed Up The Kernel Build Process

Linux 7.4 Begins Landing Patches To Speed Up The Kernel Build Process

There are notable patches by Arm engineer Lorenzo Stoakes that have begun landing in Linux 7.4 for speeding up the Linux kernel build process. This work can provide some significant reductions in the Linux kernel build time. We have been covering this effort since early September for speeding up the Linux kernel build process. It began with AI Made A Lot Of "Hideous" Code But Found Major Bottlenecks For Faster Linux Compilation with some nice build speed improvements for both the GCC and LLVM/Clang compilers. A lot of single-threaded bottlenecks and other issues are resolved by these patches. The patches in full can yield kernel builds ~36% faster and incremental builds ~70% faster. The patch series in full was further evaluated in the Phoronix special Approaching A 10 Second Linux Kernel Build. Merged today for the Linux 7.4 kernel were the initial set of changes for speeding up the kernel build process. This work includes avoiding allocating .modinfo in vmlinux, speeding up kallsyms, unnecessary sorting, only emitting relocations on the final vmlinux link, re-implementing mksysmap in C code, caching more cc-option and ld-option results, and using pigz where available for faster Gzip compression. These patches merged today as part of the Kbuild changes can be found via this pull request. Once Linux 7.4-rc1 is tagged I'll be running some fresh kernel build benchmarks for seeing the impact on these changes merged so far for expediting the Linux kernel build process.

Original Source

Read the full article at Phoronix →

KhanList aggregates and links to publicly available news content. We do not host full articles from third-party sources. Always verify important information with original sources.